@@ -3,7 +3,11 @@ use strict;
 use warnings;
 
 package App::Addex::AddressBook::Abook;
+{
+  $App::Addex::AddressBook::Abook::VERSION = '0.007';
+}
 use base qw(App::Addex::AddressBook);
+# ABSTRACT: use the "abook" program as the addex source
 
 use App::Addex::Entry::EmailAddress;
 
@@ -11,7 +15,8 @@ use File::HomeDir;
 use File::Spec;
 
 {
-  package App::Addex::AddressBook::Abook::INI::Reader;
+  package
+    App::Addex::AddressBook::Abook::INI::Reader;
   use Config::INI::Reader; # probably already loaded, but... -- rjbs, 2007-05-09
   BEGIN { our @ISA = 'Config::INI::Reader' }
 
@@ -26,38 +31,12 @@ use File::Spec;
   }
 }
 
-=head1 NAME
-
-App::Addex::AddressBook::Abook - use the "abook" program as the addex source
-
-=head1 VERSION
-
-version 0.006
-
-=cut
-
-our $VERSION = '0.006';
-
-=head1 SYNOPSIS
-
-This module implements the L<App::Addex::AddressBook> interface for the
-Mutt-friendly "abook" program.
-
-=head1 CONFIGURATION
-
-The following configuration options are valid:
-
- filename  - the address book file to read; defaults to ~/.abook/addressbook
- sig_field - the address book entry property that stores the "sig" field
- folder_field - the address book entry property that stores the "sig" field
-
-=cut
 
 sub new {
   my ($class, $arg) = @_;
 
   my $self = bless {} => $class;
-  
+
   $arg->{filename} ||= File::Spec->catfile(
     File::HomeDir->my_home,
     '.abook',
@@ -101,23 +80,42 @@ sub entries {
                 keys %{ $self->{config} };
 }
 
+1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+App::Addex::AddressBook::Abook - use the "abook" program as the addex source
+
+=head1 VERSION
+
+version 0.007
+
+=head1 SYNOPSIS
+
+This module implements the L<App::Addex::AddressBook> interface for the
+Mutt-friendly "abook" program.
+
+=head1 CONFIGURATION
+
+The following configuration options are valid:
+
+ filename  - the address book file to read; defaults to ~/.abook/addressbook
+ sig_field - the address book entry property that stores the "sig" field
+ folder_field - the address book entry property that stores the "sig" field
+
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs@cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.  I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
+This software is copyright (c) 2006 by Ricardo SIGNES.
 
-=head1 COPYRIGHT
-
-Copyright 2006-2007 Ricardo Signes, all rights reserved.
-
-This program is free software; you may redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
